<?php
/**
 * adle Theme Options
 *
 * @package adle
 * @since adle 1.0
 */
/**
 * Register the form setting for ouradle_options array.
 *
 * This function is attached to the admin_init action hook.
 *
 * This call to register_setting() registers a validation callback, adle_theme_options_validate(),
 * which is used when the option is saved, to ensure that our option values are properly
 * formatted, and safe.
 *
 * @since adle 1.0
 */
function adle_theme_options_init() {
	register_setting(
		'adle_options', // Options group, see settings_fields() call in adle_theme_options_render_page()
		'adle_theme_options', // Database option, seeadle_get_theme_options()
		'adle_theme_options_validate' // The sanitization callback, see adle_theme_options_validate()
	);
	// Register our settings field group
	add_settings_section(
		'general', // Unique identifier for the settings section
		'', // Section title (we don't want one)
		'__return_false', // Section callback (we don't want anything)
		'theme_options' // Menu slug, used to uniquely identify the page; see adle_theme_options_add_page()
	);
	// Register our individual settings fields
	add_settings_field(
		'navbar_checkbox', // Unique identifier for the field for this section
		__( 'Fixed Navigation Bar', 'adle' ), // Setting field label
		'adle_settings_field_navbar_checkbox', // Function that renders the settings field
		'theme_options', // Menu slug, used to uniquely identify the page; see adle_theme_options_add_page()
		'general' // Settings section. Same as the first argument in the add_settings_section() above
	);
	
	// Register our individual settings fields
	add_settings_field(
		'slider_checkbox', // Unique identifier for the field for this section
		__( 'Homepage Slider', 'adle' ), // Setting field label
		'adle_settings_field_slider_checkbox', // Function that renders the settings field
		'theme_options', // Menu slug, used to uniquely identify the page; see adle_theme_options_add_page()
		'general' // Settings section. Same as the first argument in the add_settings_section() above
	);
	add_settings_field( 'slider_category_select', __( 'Slider Category', 'adle' ), 'adle_settings_field_slider_category_select', 'theme_options', 'general' );
	add_settings_field( 'slider_post_count', __( 'Number of Slides', 'adle' ), 'adle_settings_field_slider_post_count', 'theme_options', 'general' );
	add_settings_field( 'social_profiles', __( 'Social Profiles - URLs', 'adle' ), 'adle_settings_field_social_profiles', 'theme_options', 'general' );
	add_settings_field( 'post_thumbs', __( 'Post Thumbnails Size', 'adle' ), 'adle_settings_field_post_thumbs', 'theme_options', 'general' );
	
}
add_action( 'admin_init', 'adle_theme_options_init' );
/**
 * Change the capability required to save the '_s_options' options group.
 *
 * @see adle_theme_options_init() First parameter to register_setting() is the name of the options group.
 * @see adle_theme_options_add_page() The edit_theme_options capability is used for viewing the page.
 *
 * @param string $capability The capability used for the page, which is manage_options by default.
 * @return string The capability to actually use.
 */
function adle_option_page_capability( $capability ) {
	return 'edit_theme_options';
}
add_filter( 'option_page_capability_adle_options', 'adle_option_page_capability' );
/**
 * Add our theme options page to the admin menu.
 *
 * This function is attached to the admin_menu action hook.
 *
 * @since adle 1.0
 */
function adle_theme_options_add_page() {
	$theme_page = add_theme_page(
		__( 'Theme Options', 'adle' ),   // Name of page
		__( 'Theme Options', 'adle' ),   // Label in menu
		'edit_theme_options',          // Capability required
		'theme_options',               // Menu slug, used to uniquely identify the page
		'adle_theme_options_render_page' // Function that renders the options page
	);
}
add_action( 'admin_menu', 'adle_theme_options_add_page' );
/**
 * Returns an array of sample select options registered for adle.
 *
 * @since adle 1.0
 */
function adle_sample_select_options() {
	$sample_select_options = array(
		'0' => array(
			'value' =>	'0',
			'label' => __( 'Zero', 'adle' )
		),
		'1' => array(
			'value' =>	'1',
			'label' => __( 'One', 'adle' )
		),
		'2' => array(
			'value' => '2',
			'label' => __( 'Two', 'adle' )
		),
		'3' => array(
			'value' => '3',
			'label' => __( 'Three', 'adle' )
		),
		'4' => array(
			'value' => '4',
			'label' => __( 'Four', 'adle' )
		),
		'5' => array(
			'value' => '5',
			'label' => __( 'Five', 'adle' )
		)
	);
	return apply_filters( 'adle_sample_select_options', $sample_select_options );
}


function adle_slider_category_select() {
	$slider_category_select = array();
    $categories = get_categories();
    foreach( $categories as $category ) {
        $slider_category_select[$category->term_id] = array(
            'label' => $category->slug,
            'value' => $category->term_id
        );
    }
    //return array('options'=>$out);
    return apply_filters( 'adle_sample_select_options', $slider_category_select );

}

function adle_slider_post_count() {
	$slider_post_count = array(
		'0' => array(
			'value' =>	'0',
			'label' => __( 'Zero', 'adle' )
		),
		'1' => array(
			'value' =>	'1',
			'label' => __( 'One', 'adle' )
		),
		'2' => array(
			'value' => '2',
			'label' => __( 'Two', 'adle' )
		),
		'3' => array(
			'value' => '3',
			'label' => __( 'Three', 'adle' )
		),
		'4' => array(
			'value' => '4',
			'label' => __( 'Four', 'adle' )
		),
		'5' => array(
			'value' => '5',
			'label' => __( 'Five', 'adle' )
		),
		'6' => array(
			'value' => '6',
			'label' => __( 'Six', 'adle' )
		),
		'7' => array(
			'value' => '7',
			'label' => __( 'Seven', 'adle' )
		),
		'8' => array(
			'value' => '8',
			'label' => __( 'Eight', 'adle' )
		),
		'9' => array(
			'value' => '9',
			'label' => __( 'Nine', 'adle' )
		),
		'10' => array(
			'value' => '10',
			'label' => __( 'Ten', 'adle' )
		),
	);
	return apply_filters( 'adle_slider_post_count', $slider_post_count );
}

/**
 * Returns an array of sample radio options registered for adle.
 *
 * @since adle 1.0
 */
function adle_post_thumbs() {
	$post_thumbs = array(
		'sthumbs' => array(
			'value' => 'sthumbs',
			'label' => __( 'Small Thumbnails', 'adle' )
		),
		'lthumbs' => array(
			'value' => 'lthumbs',
			'label' => __( 'Large Tumbnails', 'adle' )
		)
	);
	return apply_filters( 'adle_post_thumbs', $post_thumbs );
}
/**
 * Returns the options array for adle.
 *
 * @since adle 1.0
 */
function adle_get_theme_options() {
	$saved = (array) get_option( 'adle_theme_options' );
	$defaults = array(
		'navbar_checkbox'       => 'off',
		'slider_checkbox'       => 'off',
		'facebook'     => '',
		'twitter'     => '',
		'googleplus'     => '',
		'youtube'     => '',
		'linkedin'     => '',
		'pinterest'     => '',
		'instagram'     => '',
		'dribbble'     => '',
		'reddit'     => '',
		'rss'     => '',
		'slider_category_select' => '',
		'slider_post_count' => 5,
		'sample_select_options' => '',
		'post_thumbs'  => 'lthumbs',
		'sample_textarea'       => '',
	);
	$defaults = apply_filters( 'adle_default_theme_options', $defaults );
	$options = wp_parse_args( $saved, $defaults );
	$options = array_intersect_key( $options, $defaults );
	return $options;
}
/**
 * Renders the sample checkbox setting field.
 */
function adle_settings_field_navbar_checkbox() {
	$options = adle_get_theme_options();
	?>
	<label for="sample-checkbox">
		<input type="checkbox" name="adle_theme_options[navbar_checkbox]" id="sample-checkbox" <?php checked( 'on', $options['navbar_checkbox'] ); ?> />
		<?php _e( 'Tick To Enable', 'adle' ); ?>
	</label>
	<?php
}

/**
 * Renders the sample checkbox setting field.
 */
function adle_settings_field_slider_checkbox() {
	$options = adle_get_theme_options();
	?>
	<label for="slider-checkbox">
		<input type="checkbox" name="adle_theme_options[slider_checkbox]" id="slider-checkbox" <?php checked( 'on', $options['slider_checkbox'] ); ?> />
		<?php _e( 'Tick To Enable', 'adle' ); ?>
	</label>
	<?php
}

function adle_settings_field_slider_category_select() {
	$options = adle_get_theme_options();
	?>
	<select name="adle_theme_options[slider_category_select]" id="slider_category_select">
		<?php
			$selected = $options['slider_category_select'];
			$p = '';
			$r = '';
			foreach ( adle_slider_category_select() as $option ) {
				$label = $option['label'];
				if ( $selected == $option['value'] ) // Make default first in list
					$p = "\n\t<option style=\"padding-right: 10px;\" selected='selected' value='" . esc_attr( $option['value'] ) . "'>$label</option>";
				else
					$r .= "\n\t<option style=\"padding-right: 10px;\" value='" . esc_attr( $option['value'] ) . "'>$label</option>";
			}
			echo $p . $r;
		?>
	</select>
	<label class="description" for="slider_category_select[selectinput]"><?php _e( 'Sample select input', 'adle' ); ?></label>
	<?php
}

/**
 * Renders the sample select options setting field.
 */
function adle_settings_field_slider_post_count() {
	$options = adle_get_theme_options();
	?>
	<select name="adle_theme_options[slider_post_count]" id="slider_post_count">
		<?php
			$selected = $options['slider_post_count'];
			$p = '';
			$r = '';
			foreach ( adle_slider_post_count() as $option ) {
				$label = $option['label'];
				if ( $selected == $option['value'] ) // Make default first in list
					$p = "\n\t<option style=\"padding-right: 10px;\" selected='selected' value='" . esc_attr( $option['value'] ) . "'>$label</option>";
				else
					$r .= "\n\t<option style=\"padding-right: 10px;\" value='" . esc_attr( $option['value'] ) . "'>$label</option>";
			}
			echo $p . $r;
		?>
	</select>
	<label class="description" for="slider_post_count[selectinput]"><?php _e( 'Number of Slides', 'adle' ); ?></label>
	<?php
}

/**
 * Renders the sample text input setting field.
 */
function adle_settings_field_social_profiles() {
	$options = adle_get_theme_options();
	?>
	<p><input type="text" name="adle_theme_options[facebook]" id="facebook" value="<?php echo esc_attr( $options['facebook'] ); ?>" />
	<label class="description" for="facebook"><?php _e( 'Facebook', 'adle' ); ?></label></p>
	<p><input type="text" name="adle_theme_options[twitter]" id="twitter" value="<?php echo esc_attr( $options['twitter'] ); ?>" />
	<label class="description" for="twitter"><?php _e( 'Twitter', 'adle' ); ?></label></p>
	<p><input type="text" name="adle_theme_options[googleplus]" id="googleplus" value="<?php echo esc_attr( $options['googleplus'] ); ?>" />
	<label class="description" for="googleplus"><?php _e( 'Google+', 'adle' ); ?></label></p>
	<p><input type="text" name="adle_theme_options[youtube]" id="youtube" value="<?php echo esc_attr( $options['youtube'] ); ?>" />
	<label class="description" for="youtube"><?php _e( 'YouTube', 'adle' ); ?></label></p>
	<p><input type="text" name="adle_theme_options[linkedin]" id="linkedin" value="<?php echo esc_attr( $options['linkedin'] ); ?>" />
	<label class="description" for="linkedin"><?php _e( 'Linkedin', 'adle' ); ?></label></p>
	<p><input type="text" name="adle_theme_options[pinterest]" id="pinterest" value="<?php echo esc_attr( $options['pinterest'] ); ?>" />
	<label class="description" for="pinterest"><?php _e( 'Pinterest', 'adle' ); ?></label></p>
	<p><input type="text" name="adle_theme_options[instagram]" id="instagram" value="<?php echo esc_attr( $options['instagram'] ); ?>" />
	<label class="description" for="instagram"><?php _e( 'Instagram', 'adle' ); ?></label></p>
	<p><input type="text" name="adle_theme_options[dribbble]" id="dribbble" value="<?php echo esc_attr( $options['dribbble'] ); ?>" />
	<label class="description" for="dribbble"><?php _e( 'Dribbble', 'adle' ); ?></label></p>
	<p><input type="text" name="adle_theme_options[reddit]" id="reddit" value="<?php echo esc_attr( $options['reddit'] ); ?>" />
	<label class="description" for="reddit"><?php _e( 'Reddit', 'adle' ); ?></label></p>
	<p><input type="text" name="adle_theme_options[rss]" id="rss" value="<?php echo esc_attr( $options['rss'] ); ?>" />
	<label class="description" for="rss"><?php _e( 'RSS', 'adle' ); ?></label></p>
	<?php
}
/**
 * Renders the sample select options setting field.
 */
function adle_settings_field_sample_select_options() {
	$options = adle_get_theme_options();
	?>
	<select name="adle_theme_options[sample_select_options]" id="sample-select-options">
		<?php
			$selected = $options['sample_select_options'];
			$p = '';
			$r = '';
			foreach ( adle_sample_select_options() as $option ) {
				$label = $option['label'];
				if ( $selected == $option['value'] ) // Make default first in list
					$p = "\n\t<option style=\"padding-right: 10px;\" selected='selected' value='" . esc_attr( $option['value'] ) . "'>$label</option>";
				else
					$r .= "\n\t<option style=\"padding-right: 10px;\" value='" . esc_attr( $option['value'] ) . "'>$label</option>";
			}
			echo $p . $r;
		?>
	</select>
	<label class="description" for="sample_theme_options[selectinput]"><?php _e( 'Sample select input', 'adle' ); ?></label>
	<?php
}
/**
 * Renders the radio options setting field.
 *
 * @since adle 1.0
 */
function adle_settings_field_post_thumbs() {
	$options = adle_get_theme_options();
	foreach ( adle_post_thumbs() as $button ) {
	?>
	<div class="layout">
		<label class="description">
			<input type="radio" name="adle_theme_options[post_thumbs]" value="<?php echo esc_attr( $button['value'] ); ?>" <?php checked( $options['post_thumbs'], $button['value'] ); ?> />
			<?php echo $button['label']; ?>
		</label>
	</div>
	<?php
	}
}
/**
 * Renders the sample textarea setting field.
 */
function adle_settings_field_sample_textarea() {
	$options = adle_get_theme_options();
	?>
	<textarea class="large-text" type="text" name="adle_theme_options[sample_textarea]" id="sample-textarea" cols="50" rows="10" /><?php echo esc_textarea( $options['sample_textarea'] ); ?></textarea>
	<label class="description" for="sample-textarea"><?php _e( 'Sample textarea', 'adle' ); ?></label>
	<?php
}
/**
 * Renders the Theme Options administration screen.
 *
 * @since adle 1.0
 */
function adle_theme_options_render_page() {
	?>
	<div class="wrap">
		<?php $theme_name = function_exists( 'wp_get_theme' ) ? wp_get_theme() : wp_get_theme(); ?>
		<h2><?php printf( __( '%s Theme Options', 'adle' ), $theme_name ); ?></h2>
		<?php settings_errors(); ?>

		<form method="post" action="options.php">
			<?php
				settings_fields( 'adle_options' );
				do_settings_sections( 'theme_options' );
				submit_button();
			?>
		</form>
	</div><?php global $options; echo esc_attr( $options['facebook'] ); ?>
	
	<?php
}
/**
 * Sanitize and validate form input. Accepts an array, return a sanitized array.
 *
 * @see adle_theme_options_init()
 * @todo set up Reset Options action
 *
 * @param array $input Unknown values.
 * @return array Sanitized theme options ready to be stored in the database.
 *
 * @since adle 1.0
 */
function adle_theme_options_validate( $input ) {
	$output = array();
	// Checkboxes will only be present if checked.
	if ( isset( $input['navbar_checkbox'] ) )
		$output['navbar_checkbox'] = 'on';
	// Checkboxes will only be present if checked.
	if ( isset( $input['slider_checkbox'] ) )
		$output['slider_checkbox'] = 'on';
	// The sample text input must be safe text with no HTML tags
	if ( isset( $input['facebook'] ) && ! empty( $input['facebook'] ) )
		$output['facebook'] = wp_filter_nohtml_kses( $input['facebook'] );
	if ( isset( $input['twitter'] ) && ! empty( $input['twitter'] ) )
		$output['twitter'] = wp_filter_nohtml_kses( $input['twitter'] );
	if ( isset( $input['googleplus'] ) && ! empty( $input['googleplus'] ) )
		$output['googleplus'] = wp_filter_nohtml_kses( $input['googleplus'] );
	if ( isset( $input['youtube'] ) && ! empty( $input['youtube'] ) )
		$output['youtube'] = wp_filter_nohtml_kses( $input['youtube'] );
	if ( isset( $input['linkedin'] ) && ! empty( $input['linkedin'] ) )
		$output['linkedin'] = wp_filter_nohtml_kses( $input['linkedin'] );
	if ( isset( $input['pinterest'] ) && ! empty( $input['pinterest'] ) )
		$output['pinterest'] = wp_filter_nohtml_kses( $input['pinterest'] );
	if ( isset( $input['instagram'] ) && ! empty( $input['instagram'] ) )
		$output['instagram'] = wp_filter_nohtml_kses( $input['instagram'] );
	if ( isset( $input['dribbble'] ) && ! empty( $input['dribbble'] ) )
		$output['dribbble'] = wp_filter_nohtml_kses( $input['dribbble'] );
	if ( isset( $input['rss'] ) && ! empty( $input['rss'] ) )
		$output['rss'] = wp_filter_nohtml_kses( $input['rss'] );
	if ( isset( $input['reddit'] ) && ! empty( $input['reddit'] ) )
		$output['reddit'] = wp_filter_nohtml_kses( $input['reddit'] );
	// The sample select option must actually be in the array of select options
	if ( isset( $input['slider_category_select'] ) && array_key_exists( $input['slider_category_select'], adle_slider_category_select() ) )
		$output['slider_category_select'] = $input['slider_category_select'];
	// The sample select option must actually be in the array of select options
	if ( isset( $input['slider_post_count'] ) && array_key_exists( $input['slider_post_count'], adle_slider_post_count() ) )
		$output['slider_post_count'] = $input['slider_post_count'];
	// The sample select option must actually be in the array of select options
	if ( isset( $input['sample_select_options'] ) && array_key_exists( $input['slider_post_count'], adle_sample_select_options() ) )
		$output['sample_select_options'] = $input['sample_select_options'];
	// The sample radio button value must be in our array of radio button values
	if ( isset( $input['post_thumbs'] ) && array_key_exists( $input['post_thumbs'], adle_post_thumbs() ) )
		$output['post_thumbs'] = $input['post_thumbs'];
	// The sample textarea must be safe text with the allowed tags for posts
	if ( isset( $input['sample_textarea'] ) && ! empty( $input['sample_textarea'] ) )
		$output['sample_textarea'] = wp_filter_post_kses( $input['sample_textarea'] );
	return apply_filters( 'adle_theme_options_validate', $output, $input );
}